# Tuck

Semi-automated Python formatting.

The aim of this tool is to build up developer-assistance tooling for python
formatting. In general it will only format things when it needs to or when
directly instructed to.

Current capability is wrapping of various python statements (see `demo.py`) at a
location specified by the developer.
